@@ -478,10 +478,29 @@ GtkWidget *create_scrolled_window_with_text(const char *text,
                       GTK_WIDGET(text_view));
     return scrolled_window;
 }
-
+/*******************************************************************************/
+/* Free icon set list */
+void
+free_icon_set_list(GSList *iconset)
+{
+#ifdef DEBUGFUNCTIONCALL
+    START_FUNCTION;
+#endif
+    GSList *tmp = NULL;
+    if (iconset) {
+        tmp = (GSList *) iconset;
+        while (tmp) {
+            if (tmp->data)
+                g_free((gchar *) (tmp->data));
+            tmp = g_slist_next(tmp);
+        }
+        g_slist_free (iconset);
+    }
+}
 /*******************************************************************************/
 /* get icon set names */
-int create_icon_set_list(gchar *dir_path, GSList ** store, gchar *type){
+int 
+create_icon_set_list(gchar *dir_path, GSList ** store, gchar *type){
     Dirent  *dp;
     DIR     *dir_fd;
     gint    sets_number = 0,
@@ -515,7 +534,7 @@ int create_icon_set_list(gchar *dir_path, GSList ** store, gchar *type){
 GtkWidget *
 create_icon_widget(GdkPixbuf *icon_buffer, const char *icon_path, int icon_size, GSList **objects_list)
 {
-    GtkWidget *icon_widget;
+    GtkWidget *icon_widget = NULL;
 #ifdef DEBUGFUNCTIONCALL
     START_FUNCTION;
 #endif
@@ -527,9 +546,19 @@ create_icon_widget(GdkPixbuf *icon_buffer, const char *icon_path, int icon_size,
         g_object_unref(G_OBJECT(icon_buffer));
     }
 #else
+
+#ifdef HILDONANIMATION
+    if (app->config->animation){
+        icon_widget = create_hildon_clutter_icon_animation(icon_path, icon_size, objects_list);
+    }
+    if (!icon_widget)
+        icon_widget = gtk_image_new_from_pixbuf(icon_buffer);
+    g_object_unref(G_OBJECT(icon_buffer));
+#else
     icon_widget = gtk_image_new_from_pixbuf(icon_buffer);
     if (icon_buffer)
         g_object_unref(G_OBJECT(icon_buffer));
+#endif
 #endif
     return icon_widget;
 }
@@ -564,6 +593,18 @@ update_icons_set_base(const char *icon_set_name){
         close(fd);
     
     app->config->icons_set_base = g_strdup(buffer);
+    /* Create icon hash */
+
+#ifdef HILDONANIMATION 
+    /* Fix me Free memory for previous hash */
+    if (app->animation_hash)
+        app->animation_hash = clear_animation_hash(app->animation_hash);
+
+    if (app->config->animation){
+        snprintf(buffer,sizeof(buffer) - 1, "%sanimation.xml", app->config->icons_set_base);
+        app->animation_hash = parse_animation_file(buffer,"UTF-8");
+    }
+#endif
 
 #ifdef DEBUGFUNCTIONCALL
     END_FUNCTION;
@@ -697,10 +738,16 @@ browser_url(gchar *url) {
 #endif
 /*******************************************************************************/
 /* For debugging   */
-/*
-void write_log(char *string)
-{
-FILE *filelog; filelog=fopen("/tmp/omw.log","a+"); fprintf(filelog,"\n%s\n", string);fflush(filelog);fclose(filelog);
+void
+write_log(char *string){
+#ifndef RELEASE
+    FILE    *filelog;
+    filelog = fopen("/tmp/omw.log","a+");
+    if(!filelog)
+        return;
+    fprintf(filelog,"\n%s\n", string);
+    fflush(filelog);
+    fclose(filelog);
+#endif
 }
-
-*/
+/*******************************************************************************/
